# Usage

Create a `Screensaver` object with `winscr.parse_cmdline`.
It will automatically redirect stdout to `winscr.default_logfile` by default.
It will automatically redirect stderr to `winscr.default_errlog` by default.
